# PMod_TC1 module library

**MBED OS / 6.13 or later** /  *STMicroelectronics* Nucleo L476RG board

*Developed by Institut d'Optique Graduate School / France*

## Table of Contents
1. [General Info](#general-info)
2. [Ressources](#ressources)
3. [Installation](#installation)
4. [How To Use](#how-to-use)
5. [Collaboration](#collaboration)

## General Info

***PMod_TC1*** is a **MBED OS** library developed for the *Digilent* PMod module called *TC1*. 

![](https://digilent.com/reference/_media/reference/pmod/pmodtc1/pmodtc1-0.png)

This module is a cold-junction thermocouple-to-digital converter module designed for a classic K-Type thermocouple wire. With *Maxim Integrated*'s **MAX31855**, this module reports the measured temperature in 14-bits with 0.25°C resolution. 

This directory contains :

- *PMod_TC1.h* / *PMod_TC1.cpp* files : library files to include in your MBED OS project
- *main_PMod_TC1.cpp* file : an example of using this Library
- *PMod_TC1.bin* file : a precompiled file for *STMicroelectronics* Nucleo L476RG board 
- *images* directory : images used for this tutorial

## Ressources

To obtain more informations about the PMod TC1 module from Digilent, you can check the [Digilent Ressource Center page](https://digilent.com/reference/pmod/pmodtc1/start?redirect=1)

For beginners who starts programming with **Keil Studio** or **MBED Studio** on embedded STM32 targets, check this **series of tutorials** about [Nucleo board / Step by step programming](http://lense.institutoptique.fr/nucleo/)

## Installation

To use this library, you have to copy *PMod_TC1.h* / *PMod_TC1.cpp* files into the *libs* directory of your **MBED Studio** or **Keil Studio** project.

Then you have to include the header file (*PMod_TC1.h*) into your main code with the command :

```c
#include "PMod_TC1.h"
```

## How To Use

### MAX31855 ###

The *Maxim Integrated* **MAX31855** is a SPI interface device that integrates a digital temperature sensor and that converts a temperature measurement from a thermocouple into a 14-bits digital data.



### PMod_TC1 class ###

Access to the **PMod_TC1** module from *Digilent*

#### Attributes ####

```double temperature_thermo; ``` Contains the value of the thermocouple temperature.

```double temperature_internal; ``` Contains the value of the internal temperature of the MAX31855 component.

```double temperature_final; ``` Contains the value of the final measured temperture calculated as : $T_{final} = T_{thermo} - T_{internal}$

```SPI *__spi = NULL; ``` 

```DigitalOut __cs; ```

#### Methods ####

### Test code ###

```
#include "mbed.h"
#include "PMod_TC1.h"

#define WAIT_TIME_MS 500 

SPI spi_module(D11, D12, D13);
PMod_TC1 module(&spi_module, D10);

int main()
{
    double temperature = 0;
    int raw_temp = 0;

    while (true)
    {
        printf("\tTint = %lf\r\n", module.getInternalTemperature());
        printf("\tTthe = %lf\r\n", module.getThermoTemperature());
        printf("\tTraw = %x\r\n", module.readRawData());
        printf("Tfinal = %lf\r\n", module.readTemperature());
        thread_sleep_for(WAIT_TIME_MS);
    }
}
```

## Collaboration
This library was written by **Julien Villemejane** @jvillemejane for embedded programs on *STMicroelectronics* Nucleo L476RG board.  

The last modification : **Julien Villemejane** - 09/dec/2022


